import Vue from "vue";
import Keyboard from "../components/KeyboardDisplay.vue";
import router from "../router";
import store from "../store";

const inputFields = [
  ...document.getElementsByTagName("input"),
  ...document.getElementsByTagName("textarea"),
];
let keyboard = null;

const createKeyboard = (input) => {
  const keyboardDiv = document.createElement("div");
  input.parentElement.appendChild(keyboardDiv);
  keyboard = new Vue({
    router,
    store,
    render: (h) => {
      return h(Keyboard, {
        props: { inputField: input },
      });
    },
    el: keyboardDiv,
  });
};

for (const input of inputFields) {
  // Handle the case where the input is already focused when this script is loaded
  if (!keyboard && document.activeElement === input) createKeyboard(input);

  input.onfocus = () => {
    // TODO it is not possible to go from an input field to another with the keyboard global
    if (!keyboard) createKeyboard(input);
  };
  input.onblur = (e) => {
    if (!keyboard) return;
    // This is a hacky way to keep the focus on the input
    setTimeout(() => {
      if (keyboard.$el.contains(document.activeElement)) e.target.focus();
      else {
        keyboard.$destroy();
        keyboard.$el.parentElement.removeChild(keyboard.$el);
        keyboard = null;
      }
    }, 1);
  };
}
